@@ -51,7 +51,7 @@ class Holidays:
         ------
         ValueError
             * If tm argument is invalid
-        
+
         Examples
         --------
         >>> dt = datetime.now()
@@ -109,7 +109,7 @@ class Holidays:
         ------
         ValueError
             * If tm argument is invalid
-            
+
         Examples
         --------
         >>> dt = datetime.now()
@@ -127,7 +127,7 @@ class Holidays:
         """
         Return a pandas.DataFrame object with only one column
         named 'Dates' containing all the holidays.
-            
+
         Examples
         --------
         >>> h_days = get_holidays()
@@ -139,7 +139,7 @@ class Holidays:
     @classmethod
     def range_exp(self, start: str, end: str) -> pd.DataFrame:
         """
-        Return a pandas.DataFrame object with only one column named 
+        Return a pandas.DataFrame object with only one column named
         'exp' containing all the expirations between start and end.
 
         Parameters
@@ -188,21 +188,53 @@ class Holidays:
         # print(ret)
         return ret
 
+    @classmethod
+    def get_exp(self, code: str) -> str:
+        """
+        Return the expiration date of a contract code
+
+        Parameters
+        ----------
+        code : valid code string like "IF2201"
+
+        Raises
+        ------
+        ValueError
+            * If code is invalid
+            * If code is not found
+
+        Examples
+        --------
+        >>> exp = get_exp("IF2201")
+        """
+        if len(code) != 6:
+            raise ValueError("Invalid input arg")
+        ym = "20" + code[2:]
+        dt = datetime.strptime(ym, '%Y%m')
+        start = dt.strftime('%Y%m%d')
+        end = (dt + timedelta(days=30)).strftime('%Y%m%d')
+        exps = self.range_exp(start, end)
+        if len(exps['exp']) == 0:
+            raise ValueError(f"Exp for {code} not found")
+        ret = (pd.to_datetime(exps['exp'].values[0])).strftime('%Y-%m-%d')
+        # print(ret, type(ret))
+        return ret
+
     SSEHolidays = [
-    '01/01/2015', '01/02/2015', '01/03/2015', 
-    '02/18/2015', '02/19/2015', '02/20/2015', '02/21/2015', '02/22/2015', '02/23/2015', '02/24/2015', 
-    '04/06/2015', '05/01/2015', '06/20/2015', '06/21/2015', '06/22/2015', 
-    '09/03/2015', '09/04/2015', '09/05/2015', 
+    '01/01/2015', '01/02/2015', '01/03/2015',
+    '02/18/2015', '02/19/2015', '02/20/2015', '02/21/2015', '02/22/2015', '02/23/2015', '02/24/2015',
+    '04/06/2015', '05/01/2015', '06/20/2015', '06/21/2015', '06/22/2015',
+    '09/03/2015', '09/04/2015', '09/05/2015',
     '10/01/2015', '10/02/2015', '10/03/2015', '10/04/2015', '10/05/2015', '10/06/2015', '10/07/2015' ] + \
     [
-    '01/01/2016', 
-    '02/07/2016', '02/08/2016', '02/09/2016', '02/10/2016', '02/11/2016', '02/12/2016', '02/13/2016', 
-    '04/04/2016', '05/02/2016', '06/09/2016', '06/10/2016', '06/11/2016', 
-    '09/15/2016', '09/16/2016', '09/17/2016', 
+    '01/01/2016',
+    '02/07/2016', '02/08/2016', '02/09/2016', '02/10/2016', '02/11/2016', '02/12/2016', '02/13/2016',
+    '04/04/2016', '05/02/2016', '06/09/2016', '06/10/2016', '06/11/2016',
+    '09/15/2016', '09/16/2016', '09/17/2016',
     '10/01/2016', '10/02/2016', '10/03/2016', '10/04/2016', '10/05/2016', '10/06/2016', '10/07/2016' ] + \
     [
-    '01/01/2017', '01/02/2017', '01/27/2017', '01/28/2017', '01/29/2017', '01/30/2017', '01/31/2017', 
-    '02/01/2017', '02/02/2017', '04/02/2017', '04/03/2017', '04/04/2017', '05/01/2017', '05/02/2017', 
+    '01/01/2017', '01/02/2017', '01/27/2017', '01/28/2017', '01/29/2017', '01/30/2017', '01/31/2017',
+    '02/01/2017', '02/02/2017', '04/02/2017', '04/03/2017', '04/04/2017', '05/01/2017', '05/02/2017',
     '05/03/2017', '05/28/2017', '05/29/2017', '05/30/2017', '10/01/2017', '10/02/2017', '10/03/2017',
     '10/04/2017', '10/05/2017', '10/06/2017', '10/07/2017', '10/08/2017' ] + \
     [
@@ -225,17 +257,17 @@ class Holidays:
     '09/19/2021', '09/20/2021', '09/21/2021', '10/01/2021', '10/02/2021', '10/03/2021', '10/04/2021',
     '10/05/2021', '10/06/2021', '10/07/2021' ] + \
     [
-    '12/31/2021', '01/01/2022', '01/02/2022', 
-    '01/31/2022', '02/01/2022', '02/02/2022', '02/03/2022', '02/04/2022', '02/05/2022', '02/06/2022', 
-    '04/03/2022', '04/04/2022', '04/05/2022', 
+    '12/31/2021', '01/01/2022', '01/02/2022',
+    '01/31/2022', '02/01/2022', '02/02/2022', '02/03/2022', '02/04/2022', '02/05/2022', '02/06/2022',
+    '04/03/2022', '04/04/2022', '04/05/2022',
     '05/01/2022', '05/02/2022', '05/03/2022', '05/04/2022', '05/05/2022',
     '06/03/2022', '06/04/2022', '06/05/2022',
-    '09/09/2022', '09/10/2022', '09/11/2022', 
+    '09/09/2022', '09/10/2022', '09/11/2022',
     '10/01/2022', '10/02/2022', '10/03/2022', '10/04/2022', '10/05/2022', '10/06/2022', '10/07/2022' ]
 
 
 
-    
+
 if '__main__' == __name__:
     dt1 = datetime(2021,5,6)
     tm1 = "20210506"
